nxp-pac

Crates

git

Versions

lpc55s69_cm33_core1

Flavors

Sfar

Struct Sfar 

#[repr(transparent)]
pub struct Sfar(pub u32);
Secure Fault Address Register.

Tuple Fields

0: u32

Implementations

Source

impl Sfar

pub const fn address(&self) -> u32

When the SFARVALID bit of the SFSR is set to 1, this field holds the address of an access that caused an SAU violation.

pub const fn set_address(&mut self, val: u32)

When the SFARVALID bit of the SFSR is set to 1, this field holds the address of an access that caused an SAU violation.