#[repr(transparent)]pub struct Sfar(pub u32);Expand description
Secure Fault Address Register.
Tuple Fields
0: u32Implementations
Sourceimpl Sfar
impl Sfar
Sourcepub const fn address(&self) -> u32
pub const fn address(&self) -> u32
When the SFARVALID bit of the SFSR is set to 1, this field holds the address of an access that caused an SAU violation.
Sourcepub const fn set_address(&mut self, val: u32)
pub const fn set_address(&mut self, val: u32)
When the SFARVALID bit of the SFSR is set to 1, this field holds the address of an access that caused an SAU violation.